CloseAnimation enum

Defines the type of animation used to close the splash screen.

Inheritance
Available extensions

Values

none → const CloseAnimation

Closes the splash screen like a normal window, instantly without any animation.

fade → const CloseAnimation

Gradually decreases the window's opacity until it becomes fully transparent.

slideUpFade → const CloseAnimation

Slides the splash screen upwards while fading it out.

slideDownFade → const CloseAnimation

Slides the splash screen downwards while fading it out.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<CloseAnimation>
A constant List of the values in this enum, in order of their declaration.